Human IGKV families in ascending numeric order
IGKV_family_levels.RdA vector that can be used to select and arrange IGKV families. Data obtained from IMGT
Usage
as.factor(string, levels = TS::IGKV_family_levels)IGKV_family_levels.RdA vector that can be used to select and arrange IGKV families. Data obtained from IMGT
as.factor(string, levels = TS::IGKV_family_levels)