Compare number of clusters for combinations of number of PCs and resolution
TS_compare_PC_and_resolution.RdOld function. Not sure of how well it functions, or what it produces. I think this function counts the number of clusters for each combination of
'dims = 1:i'
'resolution = seq(from = 0.1, to = 2, by = 0.1)'